// ErrorCounters.js
var selectedBlades = new Array();
var selectedStorageModule1Disks = new Array();
var selectedStorageModule2Disks = new Array();
var selectedBay3ExternalPorts = new Array();
var selectedBay4ExternalPorts = new Array();

function stopWait()
{
	document.getElementById("tableFrame").style.display = "block";
	
	document.getElementById("waitDiv").style.display = "none";
	document.getElementById("tableFrame").focus();
}

function startWait()
{
	document.getElementById("tableFrame").style.display = "none";
	
	document.getElementById("waitDiv").style.display = "block";
}

function toggleResource(cell, image, array, id)
{
	// Inputs:
	// cell: the cell object that needs to be highlighted
	// image: the id of the image that represents the resource
	// array: the array (selectedBlades, selectedStorageModule1Disks, selectedStorageModule2Disks, selectedBay3ExternalPorts or selectedBay4ExternalPorts) that this resource belongs in
	// id: the resource ID (a zero indexed index into the category. ex, blade 3 would be represented by a 2 in the selectedBlades array)
	
	// Get the index of the id
	index = indexOf(id, array);
	
	if(index != -1)
	{
		// Here the resource is selected
		
		// Remove the item from the selected resources
		array.splice(index, 1);
		
		// Remove the border
		cell.className = "unSelectedResource";
		
		// Change the image alt tag
		// The alt tag will be composed of two strings: the resource name (stored in the title attribute) and a string indicating if the resource is not selected
		image = document.getElementById("resourceImage" + (id + getResourceOffset(array)) );
		image.alt = image.title + " " + document.getElementById(namespace_g + "notSelected").value;
	}
	else
	{
		// Here the resource is not selected
		
		// Add the resource to the selected resources
		array.push(id);
			
		// Add a border
		cell.className = "selectedResource";
		
		// Change the image alt tag
		// The alt tag will be composed of two strings: the resource name (stored in the title attribute) and a string indicating if the resource is selected
		image = document.getElementById("resourceImage" + (id + getResourceOffset(array)) );
		image.alt = image.title + " " + document.getElementById(namespace_g + "selected").value;
	}
	
	// Enable or disable control buttons
	if(getNumSelectedResources() == 0)
	{
		// Disable
		document.getElementById("viewErrorCountersButton").disabled = true;
		document.getElementById("resetSelectionsButton").disabled = true;
	}
	else
	{
		// Enable
		document.getElementById("viewErrorCountersButton").disabled = false;
		document.getElementById("resetSelectionsButton").disabled = false;
	}
}

function getResourceOffset(array)
{
	if(array == selectedBlades)
		return 0;
	if(array == selectedStorageModule1Disks)
		return 14;
	if(array == selectedStorageModule2Disks)
		return 34;
	if(array == selectedBay3ExternalPorts)
		return 26;
	if(array == selectedBay4ExternalPorts)
		return 30;
		
}

function indexOf(element, array)
{
	for(x = 0; x < array.length; x++)
		if(array[x] == element)
			return x;
			
	return -1;
}

function getNumSelectedResources()
{
	return selectedBlades.length + selectedStorageModule1Disks.length +  selectedStorageModule2Disks.length + selectedBay3ExternalPorts.length + selectedBay4ExternalPorts.length;
}


function viewErrorCounters()
{
	// Build the query string of selected devices
	var queryString = "";
	
	queryString += buildQueryString("blades", selectedBlades);
	queryString += buildQueryString("storageModule1Disks", selectedStorageModule1Disks);
	queryString += buildQueryString("storageModule2Disks", selectedStorageModule2Disks);
	queryString += buildQueryString("bay3ExternalPorts", selectedBay3ExternalPorts);
	queryString += buildQueryString("bay4ExternalPorts", selectedBay4ExternalPorts);
	
	// The query string will always end with an extra &, chop it off
	queryString = queryString.substring(0, queryString.length - 1);
	
	// Show the wait section while loading	
	startWait();
	document.getElementById('tableFrame').src = current_context + '/faces/page/errorcounters/ErrorCountersTable.jsp?' + queryString;
}

function buildQueryString(name, array)
{
	var result = "";
	
	for(x = 0; x < array.length; x++)
	{
		result += name + "=" + array[x] + "&";	
	}
	
	return result;
}

function resetSelections()
{
	// Unselecting all selected resources
	unselectAll(selectedBlades);
	unselectAll(selectedStorageModule1Disks);
	unselectAll(selectedStorageModule2Disks);
	unselectAll(selectedBay3ExternalPorts);
	unselectAll(selectedBay4ExternalPorts);
	
	// Resetting all arrays to empty
	selectedBlades = new Array();
	selectedStorageModule1Disks = new Array();
	selectedStorageModule2Disks = new Array();
	selectedBay3ExternalPorts = new Array();
	selectedBay4ExternalPorts = new Array();
	
	// Disable control buttons
	document.getElementById("viewErrorCountersButton").disabled = true;
	document.getElementById("resetSelectionsButton").disabled = true;
}

function unselectAll(array)
{
	for(x = 0; x < array.length; x++)
	{
		image = document.getElementById("resourceImage" + (array[x] + getResourceOffset(array)) );
		image.alt = image.title + " " + document.getElementById(namespace_g + "notSelected").value;
		
		cell = document.getElementById("resourceCell" + (array[x] + getResourceOffset(array)) );
		cell.className = "unSelectedResource";
	}
}

function matchBladeNumberAlt(bladeImageID, numberImageID)
{
	// So that the blade number alt text matches the blade image alt text
	// This is called after the blade image alt text changes due to a select/deselect
	document.getElementById(numberImageID).alt = document.getElementById(bladeImageID).alt;
}