// ports.js

// GLOBAL
// An array of tab indexes that have been requested
var requestedTabs = new Array(false, false, false);
// An array of loaded tabs
var loadedTabs = new Array(false, false, false);
// Current tab index
var currentSelectedTab = -1;
// Property pages
var expandersPage = current_context + "/faces/page/ports/ExpanderPorts.jsp";
var portListingPages = new Array(current_context+"/faces/page/ports/SASSwitchPorts.jsp", "", "");


function startHover(tabIndex)
{
	// If the tab is not the current selected tab, 
	// make the mouse cursor be the link style
	if(currentSelectedTab != tabIndex)
	{
		document.getElementById("tab" + tabIndex).style.cursor = "pointer";
	}
	else
	{
		document.getElementById("tab" + tabIndex).style.cursor = "default";
	}
}

function endHover(tabIndex)
{
	// If the tab is not the current selected tab, 
	// make the mouse cursor be the normal style
	
	if(currentSelectedTab != tabIndex)
	{
		document.getElementById("tab" + tabIndex).style.cursor = "default";
	}
}

function addTab(tabIndex, label, isClickable)
{
	tab = document.getElementById("tab" + tabIndex);
	
	tab.innerHTML = label;
	
	
	if(isClickable)
	{
		tab.onclick = function() { clickedTab(tabIndex) };
		tab.onmouseover = function() { startHover(tabIndex) };
		tab.onmouseout = function() { endHover(tabIndex) };
		
		// If it was selected before, keep it selected
		if(tabIndex == currentSelectedTab)
		{
			tab.className = "selectedTab dmc_outputText";
		}
		else
		{
			tab.className = "unselectedTab dmc_outputText";
		}
	}
	else
	{
		tab.onclick = function() { return; };
		tab.className = "unClickableTab dmc_outputText";
		
		// If a tab is not selectable, have it mandatory reload next time its clicked
		loadedTabs[tabIndex] = false;
	}
}

function removeTab(tabIndex)
{
	tab = document.getElementById("tab" + tabIndex);
	
	tab.innerHTML = "&nbsp;";
	tab.onclick = function() { return; };
	tab.className = "unClickableTab dmc_outputText";
	
	// Making sure that this tab does not appear selectable when you click away
	if(currentSelectedTab == tabIndex)
		currentSelectedTab = -1;
}

function clickedTab(tabIndex)
{
	// The same tab was clicked
	if(tabIndex == currentSelectedTab)
	{
		return;
	}
	
	// Unselect the old
	if(document.getElementById("tab" + currentSelectedTab))
	{
		document.getElementById("tab" + currentSelectedTab).className = "unSelectedTab dmc_outputText";
		
		// Make sure to hide the old frame
		document.getElementById("frame" + currentSelectedTab).style.display = "none";
	}
	
	// Selecting new
	document.getElementById("tab" + tabIndex).className = "selectedTab dmc_outputText";
	currentSelectedTab = tabIndex;
	
	// Changing the cursor style such that it is not the clickable one anymore
	document.getElementById("tab" + tabIndex).style.cursor = "default";
	
	loadTab(tabIndex);
}

function loadTab(tabIndex)
{
	// Check if the tab has already been loaded
	// Load if needed

	if(! loadedTabs[tabIndex])
	{		
		requestedTabs[tabIndex] = true;
		
		document.getElementById("frame" + tabIndex).src = portListingPages[tabIndex];
		
		// Show the wait div
		startWait(tabIndex);
	}
	else
	{
		// Here the tab is loaded, so just display it
		document.getElementById("waitDiv").style.display = "none";
	
		document.getElementById("frame" + tabIndex).style.display = "block";
	}
}

function reloadCurrentTab()
{
	// Here the currently selected tab needs to be reloaded
	
	if(! document.getElementById("tab" + currentSelectedTab))
	{
		return;
	}
	
	// Set the loaded to be false
	loadedTabs[currentSelectedTab] = false;
	
	loadTab(currentSelectedTab);
}

function startWait(tabIndex)
{
	document.getElementById("waitDiv").style.display = "block";
	
	document.getElementById("frame" + tabIndex).style.display = "none";
}

function stopWait(tabIndex)
{
	// Make sure that this frame has been requested before
	// Frames will fire an onLoad->stopWait event when they load with src = ""
	// We need to detect and skip that case
	if(!requestedTabs[tabIndex])
	{
		return;
	}
	
	// Here a frame has finished loading, note it in the array
	loadedTabs[tabIndex] = true;
	
	// Display this tab only if its the current one
	if(tabIndex == currentSelectedTab)
	{
		document.getElementById("waitDiv").style.display = "none";
	
		document.getElementById("frame" + currentSelectedTab).style.display = "block";
		document.getElementById("frame" + currentSelectedTab).focus();
	}
}

function switchTab(thisEvent){
	var keyCode = thisEvent.keyCode;
	
	if (keyCode == 37) {
		for (i=currentSelectedTab-1;i>-1;i--) {
			if (isTabAvailable(i)) {
				clickedTab(i);
				break;
			}
		}

	} else if (keyCode == 39) {
		for (i=currentSelectedTab+1;i<3;i++) {
			if (isTabAvailable(i)) {
				clickedTab(i);
				break;
			}
		}
	}
	
}

function isTabAvailable(tabIndex)
{
	tab = document.getElementById("tab" + tabIndex);
	if (tab.className == "unClickableTab dmc_outputText") return false;
	return true;
}